## Markdown Card

<script type="module" src="/web_components/js/elements/markdown/WebC__Markdown__Card.mjs"></script>

<webc-markdown-card content_path='en/web-pages/demos/index.md'></webc-markdown-card>